﻿/**
 *       Project: ServerLib
 *     Copyright: Copyright (C) 2008, Rob Kennedy
 *   Create Date: 2008-07-16 10:40 PM
 * Modified Date: 2008-07-16 10:40 PM    RK  Added comments
 *      Comments: Ignore SA1633.
 *      
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace ServerLib.Settings
{
    using System.Collections.ObjectModel;
    using System.Data;
    using ServerLib.Core;
    using ServerLib.Data;
    
    /// --------------------------------------------------------------------
    /// Project	 : ServerLib
    /// Class	 : Folder
    /// Inherits : DataRowRecord
    /// --------------------------------------------------------------------
    /// <summary>
    /// A class representation of a Folder database record
    /// </summary>
    /// <authorname>Rob Kennedy</authorname>
    /// <remarks></remarks>
    /// --------------------------------------------------------------------
    public class Folder : DataRowRecord
    {
        #region Private Properties
        /// <summary>Contains a collection list of messages in the folder</summary>
        private Collection<Message> folderMessages = new Collection<Message>();
        #endregion

        #region Public Properties

        /// <summary>
        /// Gets the unique Folder record Identifier number
        /// </summary>
        public int FolderID
        {
            get
            {
                return Types.FixInteger(this.InternalDataRow["FolderID"]);
            }
        }

        /// <summary>
        /// Gets or sets the unique user id for the folder owner
        /// </summary>
        public int UserID
        {
            get
            {
                return Types.FixInteger(this.InternalDataRow["UserID"]);
            }

            set
            {
                if (this.InternalDataRow.RowState == System.Data.DataRowState.Unchanged)
                {
                    this.InternalDataRow.BeginEdit();
                }

                this.InternalDataRow["UserID"] = value;
            }
        }

        /// <summary>
        /// Gets or sets the folder name value
        /// </summary>
        public string FolderName
        {
            get
            {
                return Types.FixString(this.InternalDataRow["FolderName"]);
            }

            set
            {
                if (this.InternalDataRow.RowState == System.Data.DataRowState.Unchanged)
                {
                    this.InternalDataRow.BeginEdit();
                }

                this.InternalDataRow["FolderName"] = value;
            }
        }

        /// <summary>
        /// Gets a collection of messages associated with the folder
        /// </summary>
        public Collection<Message> Messages
        {
            get
            {
                if (this.Connection != null)
                {
                    this.folderMessages.Clear();

                    bool wasPreviouslyOpen = this.Connection.IsConnected;

                    if (!wasPreviouslyOpen)
                    {
                        this.Connection.Open();
                    }

                    if (this.Connection.IsConnected)
                    {
                        DataTable resultsTable = this.Connection.SelectQuery(SqlCommandStringBuilder.BuildSelect("Messages", null, string.Format("WHERE FolderID={0}", this.FolderID), string.Empty));

                        if (resultsTable != null)
                        {
                            foreach (DataRow messageRow in resultsTable.Rows)
                            {
                                this.folderMessages.Add(new Message(messageRow));
                            }
                        }
                    }

                    if (!wasPreviouslyOpen)
                    {
                        this.Connection.Close();
                    }
                }

                return this.folderMessages;
            }
        }
        #endregion

        #region Public Constructors

        /// <summary>
        /// Initializes the Alias object with a new DataRow class
        /// </summary>
        /// <param name="dataConnection">The IDatabase object to connect with</param>
        public Folder(IDatabase dataConnection)
            : base(dataConnection)
        {
        }

        /// <summary>
        /// Initializes the Alias object with a new DataRow class
        /// </summary>
        /// <param name="dataConnection">The IDatabase object to connect with</param>
        /// <param name="tableName">The Record table name to load into the Record object</param>
        /// <param name="fieldName">The Record table field name name used to identify when loading the recordId</param>
        /// <param name="recordId">The unique record ID number to load into the Record object</param>
        public Folder(IDatabase dataConnection, string tableName, string fieldName, int recordId)
            : base(dataConnection, tableName, fieldName, recordId)
        {
        }

        /// <summary>
        /// Initializes the Alias object with a new DataRow class
        /// </summary>
        /// <param name="dataTable">The DataTable object to retrieve a new DataRow object from</param>
        public Folder(DataTable dataTable)
            : base(dataTable)
        {
        }
        
        /// <summary>
        /// Initializes the Alias object with a new DataRow class
        /// </summary>
        /// <param name="dataRow">The DataRow object to initialize the Domain object with</param>
        public Folder(DataRow dataRow)
            : base(dataRow)
        {
        }
        #endregion
    }
}
